@@ -12,6 +12,7 @@ from json_database.utils.combo_lock import ComboLock, DummyLock
 from tempfile import gettempdir
 
 LOG = logging.getLogger("JsonDatabase")
+LOG.setLevel("INFO")
 
 
 class JsonStorage(dict):
@@ -23,8 +24,6 @@ class JsonStorage(dict):
         super().__init__()
         lock_path = join(gettempdir(), path.split("/")[-1] + ".lock")
         if disable_lock:
-            LOG.warning("Lock is disabled, database might get corrupted if "
-                        "different processes try to use it at same time!")
             self.lock = DummyLock(lock_path)
         else:
             self.lock = ComboLock(lock_path)
@@ -104,10 +103,14 @@ class JsonStorage(dict):
 
 class JsonDatabase(dict):
     """ searchable persistent dict """
-    def __init__(self, name, path=None, disable_lock=False):
+    def __init__(self,
+            name,
+            path=None,
+            disable_lock=False,
+            extension="json"):
         super().__init__()
         self.name = name
-        self.path = path or self.name + ".json"
+        self.path = path or f"{name}.{extension}"
         self.db = JsonStorage(self.path, disable_lock=disable_lock)
         self.db[name] = []
         self.db.load_local(self.path)
@@ -278,10 +281,13 @@ class JsonDatabase(dict):
 class JsonStorageXDG(JsonStorage):
     """ xdg respectful persistent dicts """
 
-    def __init__(self, name, xdg_folder=BaseDirectory.xdg_cache_home,
-                 disable_lock=False, subfolder="json_database"):
+    def __init__(self,
+                 name,
+                 xdg_folder=BaseDirectory.xdg_cache_home,
+                 disable_lock=False, subfolder="json_database",
+                 extension="json"):
         self.name = name
-        path = join(xdg_folder, subfolder, name + ".json")
+        path = join(xdg_folder, subfolder, f"{name}.{extension}")
         super().__init__(path, disable_lock=disable_lock)
 
 
@@ -289,13 +295,16 @@ class JsonDatabaseXDG(JsonDatabase):
     """ xdg respectful json database """
 
     def __init__(self, name, xdg_folder=BaseDirectory.xdg_data_home,
-                 disable_lock=False, subfolder="json_database"):
-        path = join(xdg_folder, subfolder, name + ".jsondb")
-        super().__init__(name, path, disable_lock=disable_lock)
+                 disable_lock=False, subfolder="json_database",
+                 extension="jsondb"):
+        path = join(xdg_folder, subfolder, f"{name}.{extension}")
+        super().__init__(name, path, disable_lock=disable_lock, extension=extension)
+
 
 class JsonConfigXDG(JsonStorageXDG):
     """ xdg respectful config files, using json_storage.JsonStorageXDG """
 
     def __init__(self, name, xdg_folder=BaseDirectory.xdg_config_home,
-                 disable_lock=False, subfolder="json_database"):
-        super().__init__(name, xdg_folder, disable_lock, subfolder)
+                 disable_lock=False, subfolder="json_database",
+                 extension="json"):
+        super().__init__(name, xdg_folder, disable_lock, subfolder, extension)
